@@ -366,6 +366,13 @@ sub read_attribute_for_html {
   return $self->read_attribute_for_validation($attribute);
 }
 
+sub get_attribute_for_json {
+  my ($self, $attribute) = @_;
+  return $self->is_marked_for_deletion if $attribute eq '_delete';
+  return 1 if $attribute eq '_add';
+  return $self->read_attribute_for_validation($attribute);
+}
+
 # Provide basic uniqueness checking for columns.  This is basically a dumb DB lookup.  
 # Its probably fine for light work but you'll need something more performant when your
 # table gets big.
@@ -646,7 +653,7 @@ sub set_multi_related_from_params {
   debug 2, "starting loop to update/create related $related (total @{[ scalar @param_rows ]} rows in loop)";
   foreach my $param_row (@param_rows) {
     debug 3, "top of new loop on param_rows";
-    if($param_row->{_nop}) {
+    if(exists $param_row->{_nop}) {
       debug 3, "Is a NOP row, so skipping";
       next;
     }
