@@ -2,9 +2,9 @@ package Retiree;
 
 use Moo;
 use Valiant::Validations;
+use Valiant::I18N;
 
 extends 'Person';
-with 'TestRole';
 
 has 'retirement_date' => (is=>'ro');
 
@@ -17,6 +17,13 @@ validates 'retirement_date' => (
 
 validates_with 'Custom', notes=>'123';
 
+validates_with sub {
+  my ($self) = @_;
+  $self->errors->add(undef, 'Failed Retiree validation');
+  $self->errors->add('name', 'bad retiree name');
+};
+
+
 validates ['age', 'name'], sub {
   my ($self, $attr_name, $value) = @_;
   $self->errors->add($attr_name => _t('log'), +{value=>$value});
@@ -33,4 +40,6 @@ validates 'name' => (
   if => sub { 1 },
 );
 
+with 'TestRole';  # put this here to test proper ordering
+
 1;
